@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "shrface" "2.6.5"
+(define-package "shrface" "20250923.958"
   "Extend shr/eww with org features and analysis capability."
   '((emacs              "25.1")
     (org                "9.0")
     (language-detection "0.1.0"))
   :url "https://github.com/chenyanming/shrface"
-  :commit "0c98fa80bf8fc7f0864cd30063202235e12b8ad4"
-  :revdesc "0c98fa80bf8f"
+  :commit "6d5b730c09cbbb070abadab1b2039677b74e3c62"
+  :revdesc "6d5b730c09cb"
   :keywords '("faces")
   :authors '(("Damon Chan" . "elecming@gmail.com"))
   :maintainers '(("Damon Chan" . "elecming@gmail.com")))
