@@ -6,8 +6,8 @@
 ;; URL: https://github.com/chenyanming/shrface
 ;; Keywords: faces
 ;; Created: 10 April 2020
-;; Package-Version: 2.6.5
-;; Package-Revision: 0c98fa80bf8f
+;; Package-Version: 20250923.958
+;; Package-Revision: 6d5b730c09cb
 ;; Package-Requires: ((emacs "25.1") (org "9.0") (language-detection "0.1.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -940,6 +940,17 @@ Argument DOM dom."
   (shrface-shr-fontize-dom dom '(comment t) 'shrface-description-list-term-face)
   (shr-ensure-newline))
 
+(defun shrface-tag-hr (dom)
+  "Fontize tag hr.
+Argument DOM dom."
+  (shr-ensure-newline)
+  (insert (propertize (make-string (if (not shr-use-fonts)
+                                       shrface-hr-width
+                                     (1+ (/ shrface-hr-width
+                                            shr-table-separator-pixel-width)))
+                                   shrface-hr-line) 'face 'shrface-hr-face)
+          "\n"))
+
 (defun shrface-tag-rt (dom)
   "Render the <rt> (ruby text) element by creating raised overlays for annotation text.
 
@@ -959,6 +970,23 @@ This assumes the annotation belongs above the immediately preceding character."
     (unless (stringp sub)
       (shr-descend sub))))
 
+(defun shrface-tag-rt-bracketize (dom)
+  "Render the <rt> (ruby text) element by creating raised overlays for annotation text.
+
+DOM is the parsed HTML DOM node representing the <rt> tag.
+This function looks for string children in the DOM and displays them as ruby annotations
+using `shrface-add-rt-overlay`, without modifying the buffer text.
+
+This assumes the annotation belongs above the immediately preceding character."
+  (dolist (sub (dom-children dom))
+    (when (stringp sub)
+      (let ((rt-text (string-trim sub)))
+        (insert (format "[%s]" rt-text))))
+    ;; If not string, recurse
+    (unless (stringp sub)
+      (shr-descend sub))))
+
+
 (defun shrface-add-rt-overlay (pos base-char rt-text)
   "Display RT-TEXT (ruby/furigana annotation) above BASE-CHAR at position POS using an overlay.
 
@@ -1839,6 +1867,7 @@ Detail uses cases can be found at test.el."
                  (li . shrface-tag-li)
                  (p . shrface-tag-p)
                  (a . shrface-tag-a)
+                 (rt   . shrface-tag-rt-bracketize)
                  (h6 . shrface-tag-h6)
                  (h5 . shrface-tag-h5)
                  (h4 . shrface-tag-h4)
